@@ -10,7 +10,9 @@ import genice2.lattices
 desc = {"ref": {"Methane A": 'Maynard-Casely 2010',
                 "R": 'Mochizuki 2014'},
         "usage": "No options available.",
-        "brief": "Hypothetical ice R."
+        "brief": "Hypothetical ice R.",
+        "test": ({"args": "",
+                  "options": "--depol=optimal"},)
         }
 
 
