@@ -10,7 +10,9 @@ from genice2.cell import cellvectors
 import genice2.lattices
 desc = {"ref": {"T2": 'Yagasaki 2018'},
         "usage": "No options available.",
-        "brief": "Hypothetical ice T2."
+        "brief": "Hypothetical ice T2.",
+        "test": ({"args": "",
+                  "options": "--depol=optimal"},)
         }
 
 
